#!/usr/bin/python2
#-*-python-*-

import cf
import tempfile
import os
import sys
import numpy

'''
Test the cf package:
'''

print '\nTEST: Set chunk size:'

# Save original chunksize
original_chunksize = cf.CHUNKSIZE()

cf.CHUNKSIZE(60)
print '\nCHUNKSIZE reset to',cf.CHUNKSIZE()

print '\nTEST: Create a field in memory:'

f = cf.Field()
f.space = cf.Space()
 
f.standard_name = 'test_field'

f.space['dim0'] = cf.Coordinate()
f.space['dim0'].standard_name = 'latitude'
f.space['dim0'].Data = cf.Data(numpy.arange(10, dtype = float), 'degrees_north', chunk=0)
 
f.space['dim1'] = cf.Coordinate()
f.space['dim1'].standard_name = 'longitude'
f.space['dim1'].Data = cf.Data(numpy.arange(9, dtype = float) + 20, 'degrees_east', chunk=0)

f.space.dimensions = {'data': ['dim0', 'dim1'],
                      'dim0': ['dim0'],
                      'dim1': ['dim1'],
                      }

f.space.dimension_sizes = {'dim0': 10,
                           'dim1': 9,
                          }

f.Data = cf.Data(numpy.arange(90, dtype = float).reshape(10,9), 'm s-1', chunk=0)

f.finalize()

print '\nTEST: Print a dump of the field:'
print repr(f)

print f.dump()

print '\nTEST: Write the field to disk:'
file = tempfile.mktemp('.nc')

cf.write(f, file)

print '\nTEST: Read the field from disk:'
g = cf.read(file)[0]
try:
    g.delpub('history')
except AttributeError:
    pass

print g.dump()

print '\nTEST: Access the field\'s data as a numpy array:'
print g.array

print '\nTEST: Access the field\'s coordinates\' data as a numpy arrays:'

print g.coord('lat').array
print g.coord('lon').array

print '\nTEST: Subset the field:'
print g.subset(latitude = cf.lt(5), longitude = 27)

print '\nTEST: Subset the field:'
print g.subset[..., 2:5].array

print '\nTEST: Subset the field:'
print g.subset[9::-4, ...].array

print '\nTEST: Check the equality function:'
result  = cf.equals(g, g)
print result
if not result:
    raise RuntimeError('Field is not equal to itself')

print '\nTEST: Create list of fields:'
fl = cf.FieldList([g, g, g, g])

print '\nTEST: Write a list of fields to disk:'
cf.write(fl, file)

print '\nTEST: Read a list of fields from disk:'
fl = cf.read(file)
try:
    fl.delpub('history')
except AttributeError:
    pass

print repr(fl)

print '\nTEST: Print all fields in the list:'
print fl

print '\nTEST: Print the last field in the list:'
print fl[-1]

print '\nTEST: Print the data of the last field in the list:'
print fl[-1].array

print '\nTEST: Modify the last field in the list:'
fl[-1] *= -1
print fl[-1].array

print '\nTEST: Combine fields not in place:'
g = fl[-1] - fl[-1]
print g.array

print '\nTEST: Reset chunk size:'
cf.CHUNKSIZE(original_chunksize)
print '\nCHUNKSIZE reset to',cf.CHUNKSIZE()

print '\n-----------------------------------------------'
print   'TEST: All tests passed for cf version', cf.__version__
print   '----------------------------------------------- '

# Tidy up
os.remove(file)
